WindowsCookieManagerCreationParams class

Object specifying creation parameters for creating a WindowsCookieManager.

When adding additional fields make sure they can be null or have a default value to avoid breaking changes. See PlatformCookieManagerCreationParams for more information.

Annotations

Constructors

WindowsCookieManagerCreationParams({WindowsWebViewEnvironment? webViewEnvironment})
Creates a new WindowsCookieManagerCreationParams instance.
const
WindowsCookieManagerCreationParams.fromPlatformCookieManagerCreationParams(PlatformCookieManagerCreationParams params)
Creates a WindowsCookieManagerCreationParams instance based on PlatformCookieManagerCreationParams.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webViewEnvironment → WindowsWebViewEnvironment?
Used to create the PlatformCookieManager using the specified environment.
final

Methods

isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
inherited
isPropertySupported(PlatformCookieManagerCreationParamsProperty property, {TargetPlatform? platform}) → bool
Check if the given property is supported by the defaultTargetPlatform or a specific platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited